# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

from pathlib import Path

try:
    import tomllib
except ImportError:
    import tomli as tomllib

with (Path(__file__).parent.parent / "pyproject.toml").open("rb") as f:
    _pyproject = tomllib.load(f)

# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

project = _pyproject["project"]["name"]
author = ", ".join([a["name"] for a in _pyproject["project"]["authors"]])
copyright = f"2024, {author}"
version = str(_pyproject["project"].get("version", "DEV"))
release = version

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

extensions = ["sphinx.ext.intersphinx"]

templates_path = ["_templates"]
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]


# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

html_theme = "alabaster"

intersphinx_mapping = dict(
    flask=("https://flask.palletsprojects.com/en/3.0.x/", None),
    flask_multipass=("https://flask-multipass.readthedocs.io/en/latest/", None),
    flask_sqlalchemy=("https://flask-sqlalchemy.palletsprojects.com/en/3.1.x/", None),
    gunicorn=("https://docs.gunicorn.org/en/stable/", None),
)
