from uuid import UUID

from uuid_extensions import uuid7

from sqlalchemy import String, Text, Uuid
from sqlalchemy.orm import Mapped, mapped_column

from flask_wtf import FlaskForm

from wtforms import fields, validators

from . import db


class Schild(db.Model):
    ident: Mapped[UUID] = mapped_column(Uuid, primary_key=True, default=uuid7)
    title: Mapped[str] = mapped_column(String(31))
    text: Mapped[str] = mapped_column(Text)
    image: Mapped[str] = mapped_column(String(255), nullable=True)
    template: Mapped[str] = mapped_column(String(255))


class SchildForm(FlaskForm):
    title = fields.StringField(
        "Titel",
        validators=[
            validators.InputRequired(),
            validators.Length(max=Schild.title.type.length),
        ],
    )
    text = fields.TextAreaField(
        "Text",
        validators=[validators.InputRequired()],
    )
    image = fields.RadioField(
        "Bild",
        validators=[validators.Optional()],
    )
    template = fields.RadioField(
        "Vorlage",
        validators=[validators.DataRequired()],
    )


class PrintForm(FlaskForm):
    printer = fields.SelectField("Drucker")
    copies = fields.IntegerField(
        "Kopien",
        default=1,
        validators=[validators.NumberRange(1, 10), validators.InputRequired()],
    )
